@@ -12,7 +12,7 @@ class Trello:
             key=None,
             token=None,
             loop=asyncio.get_event_loop(),
-            session=None,
+            #session=None,
             cache_mode="full"
         ):
         """Initializes a new Trello client.
@@ -45,10 +45,12 @@ class Trello:
         self._cache_mode = cache_mode
         self._last_card_limit = None
 
+        """
         if session:
             self.session = session
         else:
             self.session = aiohttp.ClientSession(loop=loop)
+        """
 
     async def get_board(self, a, card_limit=None, list_limit=None):
         if not self.synced:
@@ -93,7 +95,7 @@ class Trello:
             key=self.key,
             token=self.token,
             loop=self.loop,
-            session=self.session,
+            #session=self.session,
             params={"members": "all"}
         )
 
@@ -123,7 +125,7 @@ class Trello:
             token=self.token,
             loop=self.loop,
             params=kwargs,
-            session=self.session
+            #session=self.session
         ), trello_instance=self)
 
         if self._cache_mode in ("full", "some"):
